@@ -1,6 +1,6 @@
 # -*- coding: utf-8 -*-
-# Gufw 14.10.1 - http://gufw.org
-# Copyright (C) 2008-2014 Marcos Alvarez Costales https://launchpad.net/~costales
+# Gufw 15.04.0 - http://gufw.org
+# Copyright (C) 2008-2015 Marcos Alvarez Costales https://launchpad.net/~costales
 #
 # Gufw is free software; you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
@@ -112,6 +112,9 @@ class Gufw:
         
         self.web = self.builder.get_object('boxWeb')
         self.web_content = WebKit.WebView()
+        settings = self.web_content.get_settings()
+        settings.set_property('enable-default-context-menu', False)
+        self.web_content.set_settings(settings)
         self.web.add(self.web_content)
         # For ORCA
         self.tuto_label = Gtk.Label()
@@ -294,7 +297,6 @@ class Gufw:
         f.close()
         
         replace_html = dict(heading1=_("Getting started"),
-                            welcome=_("What is Gufw?"),
                             intro=_("An uncomplicated way to manage your firewall, powered by ufw. Easy, simple, nice and useful! :)"),
                             heading2=_("Basic"),
                             heading3=_("FAQ"),
@@ -306,7 +308,7 @@ class Gufw:
                             faq2_q=_("Why is Gufw disabled by default?"),
                             faq2_a=_("By default, the firewall does not open ports to the outside world."),
                             faq3_q=_("Some rules are added by themselves?"),
-                            faq3_a=_("Well, the behaviour is such that when you change or import a profile, or when you edit a rule, Gufw readds that rule, then ufw readds for IPv4 and IPv6."),
+                            faq3_a=_("Well, the behaviour is such that when you change or import a profile, or when you edit a rule, Gufw will add that rule again, then ufw re-adds that rule for IPv4 and IPv6."),
                             faq4_q=_("What is Allow, Deny, Reject and Limit?"),
                             faq4_a1=_("Allow: Will allow traffic."),
                             faq4_a2=_("Deny: Will deny traffic."),
@@ -316,22 +318,8 @@ class Gufw:
                             faq5_a=_("All the ufw rules will be appear in all profiles."),
                             faq6_q=_("What do I see in the Listening Report?"),
                             faq6_a=_("The ports on the live system in the listening state for TCP and the open state for UDP."),
-                            faq7_q=_("Can I use Gufw in a remote computer or without graphical environment, as Ubuntu Server?"),
-                            faq7_a1=_("Yes! Export your X display ;) You will need a client \"A\" with graphic environment and a server \"B\" with Gufw. Then, run from client \"A\":"),
-                            faq7_a2 = "ssh user_in_B@IP_of_B -X",
-                            faq7_a3 = "sudo /usr/bin/gufw-pkexec -ssh",
-                            faq7_a4=_("Gufw will appear in your client \"A\" and all the operations will be apply in the server \"B\". Please, read the community documentation for a complete information."),
                             faq8_q=_("I want even more!"),
-                            faq8_a=_("You'll find more information in the community documentation :)"),
-                            faq9_q=_("How can I forward my IP/Ports?"),
-                            faq9_a1=_("To routing policy and rules, you must setup IP forwarding in the system:"),
-                            faq9_a2=_("Close Gufw"),
-                            faq9_a3=_("Uncomment these 3 lines in the file") + " /etc/ufw/sysctl.conf:",
-                            faq9_a4="&nbsp;&nbsp; #net/ipv4/ip_forward=1",
-                            faq9_a5="&nbsp;&nbsp; #net/ipv6/conf/default/forwarding=1",
-                            faq9_a6="&nbsp;&nbsp; #net/ipv6/conf/all/forwarding=1",
-                            faq9_a7=_("Reload the firewall: ") + "sudo ufw reload",
-                            faq9_a8=_("Open Gufw, you'll see a new \"Routed\" option (with an arrow around the shield) and you can forward any rule from the Update window or Advanced Tab in Add window."))
+                            faq8_a=_("You'll find more information in the community documentation :)"))
         html = Template(html_content).safe_substitute(replace_html)
         self.web_content.load_html_string(html, "file:///")
     
